from tfe_run_wait.cli import _apply


def main():
    exit(_apply())


if __name__ == "__main__":
    main()
